@@ -285,7 +285,7 @@ _get_event_type_icon(ScoutWindow* self, const gint event_type)
 {
   GdkPixbuf* event_type_icon = NULL;
   event_type_icon = GDK_PIXBUF(g_hash_table_lookup(self->priv->cached_calendar_type_icon,
-						   &event_type));
+						   (gpointer)event_type));
   if(!event_type_icon)
   {
     switch(event_type)
@@ -326,7 +326,7 @@ _get_calendar_id_icon(ScoutWindow* self, const gint calendar_id)
 {
   GdkPixbuf* calendar_id_icon = NULL;
   calendar_id_icon = GDK_PIXBUF(g_hash_table_lookup(self->priv->cached_calendar_id_icon,
-						    &calendar_id));
+						    (gpointer)calendar_id));
   if(!calendar_id_icon)
   {
     int error = 0;
@@ -398,6 +398,8 @@ _get_calendar_id_icon(ScoutWindow* self, const gint calendar_id)
 static GdkPixbuf*
 _get_contact_attribute_icon(ScoutWindow* self, const gchar* attribute)
 {
+  if(attribute == NULL)
+    return NULL;
   GdkPixbuf* attribute_icon = NULL;
   attribute_icon = GDK_PIXBUF(g_hash_table_lookup(self->priv->cached_contact_attribute_icons,
 					       attribute));
@@ -492,6 +494,8 @@ _get_contact_attribute_icon(ScoutWindow* self, const gchar* attribute)
 static GdkPixbuf*
 _get_account_icon(ScoutWindow* self, const gchar* account_uid)
 {
+  if(account_uid == NULL)
+    return NULL;
   GdkPixbuf* account_icon = NULL;
   account_icon = GDK_PIXBUF(g_hash_table_lookup(self->priv->cached_account_icon,
 					       account_uid));
@@ -533,6 +537,8 @@ _get_account_icon(ScoutWindow* self, const gchar* account_uid)
 static GdkPixbuf*
 _get_contact_avatar_icon(ScoutWindow* self, const gchar* abook_uid)
 {
+  if(abook_uid == NULL)
+    return NULL;
   GdkPixbuf* avatar_icon = NULL;
   avatar_icon = GDK_PIXBUF(g_hash_table_lookup(self->priv->cached_contact_avatar,
 					       abook_uid));
@@ -561,9 +567,9 @@ _get_contact_avatar_icon(ScoutWindow* self, const gchar* abook_uid)
 					     HILDON_ICON_PIXEL_SIZE_FINGER, GTK_ICON_LOOKUP_NO_SVG, NULL);
     }
     if(avatar_icon == NULL)
-      {
-	g_warning("pushd NULL icon \n");
-      }
+    {
+      g_warning("pushd NULL icon \n");
+    }
     g_hash_table_insert(self->priv->cached_contact_avatar,
 			g_strdup(abook_uid),
 			avatar_icon);
@@ -722,7 +728,6 @@ _search_in_events(ScoutWindow* self,
   {
     gchar* free_text = NULL;
     rtcom_el_iter_get_values(rtcom_iter, "free-text", &free_text, NULL);
-    glong pos = -1;
     gchar* prefix = NULL;
     gchar* suffix = NULL;
     if(_find_in_text(self, free_text, &prefix, &suffix))
@@ -742,7 +747,8 @@ _search_in_events(ScoutWindow* self,
 	gchar time_string[256];
 	struct tm* time_stamp;
 	time_stamp = localtime(&start_time);
-	strftime(time_string, 256, _get_date_time_format(), time_stamp);
+	strftime(time_string, 255, _get_date_time_format(), time_stamp);
+	time_string[255] = '\0';
 	gchar* remote_name = _get_remote_name(self, remote_uid);
 	gchar* abook_uid = _get_abook_uid_name(self, remote_uid);
 
@@ -770,7 +776,6 @@ _search_in_events(ScoutWindow* self,
 				  suffix);
 	g_free(label_text);
 
-
 	if(outgoing == 1)
 	{
 	  _add_result_entry(self,
@@ -795,7 +800,6 @@ _search_in_events(ScoutWindow* self,
 	}
 	g_free(remote_name);
 	g_free(abook_uid);
-
 	g_free(text_name);
       }
       g_free(remote_uid);
@@ -961,7 +965,11 @@ _search_and_insert_contact_attribute(ScoutWindow* self, OssoABookContact* contac
        _find_in_text(self, value, &prefix, &suffix))
     {
       const gchar* abook_uid = osso_abook_contact_get_persistent_uid(contact);
-      GdkPixbuf* avatar_icon = _get_contact_avatar_icon(self, abook_uid);
+      GdkPixbuf* avatar_icon = NULL;
+      if(abook_uid)
+      {
+	avatar_icon = _get_contact_avatar_icon(self, abook_uid);
+      }
       GdkPixbuf* attribute_icon = _get_contact_attribute_icon(self, e_contact_field);
 
       gchar* text_name = 
@@ -1035,7 +1043,7 @@ search_in_contacts(ScoutWindow* self)
     {
       continue;
     }
-    const GList *fields = (GList*)osso_abook_account_manager_get_primary_vcard_fields(self->priv->acc_manager);
+    const GList *fields = (const GList*)osso_abook_account_manager_get_primary_vcard_fields(self->priv->acc_manager);
     for (;fields; fields = fields->next) 
     {
       if(_search_and_insert_contact_attribute(self, original_contact, (const gchar*)fields->data))
@@ -1629,12 +1637,12 @@ scout_window_init(ScoutWindow* self)
   self->priv = SCOUT_WINDOW_GET_PRIVATE(self);
   _init_rtcom(self);
   self->priv->cached_calendar_id_icon = 
-    g_hash_table_new_full(g_str_hash, g_str_equal,
-			  (GDestroyNotify) g_free, (GDestroyNotify) g_object_unref);
-
+    g_hash_table_new_full(g_direct_hash, g_direct_equal,
+			  NULL, (GDestroyNotify) g_object_unref);
   self->priv->cached_calendar_type_icon = 
-    g_hash_table_new_full(g_int_hash, g_int_equal,
-			  (GDestroyNotify) g_free, (GDestroyNotify) g_object_unref);
+    g_hash_table_new_full(g_direct_hash, g_direct_equal,
+			  NULL, (GDestroyNotify) g_object_unref);
+
   self->priv->cached_contact_attribute_icons = 
     g_hash_table_new_full(g_str_hash, g_str_equal,
 			  (GDestroyNotify) g_free, (GDestroyNotify) g_object_unref);
